<?php
$TRANSLATIONS = array(
"Ok" => "Ok",
"Cancel" => "Cancelar",
"OK" => "OK",
"Import" => "Importar",
"Unknown error" => "Error desconocido",
"Download" => "Descargar",
"Share" => "Compartir",
"Export" => "Exportar",
"Password" => "Clave"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
